aboutsummaryrefslogtreecommitdiff
path: root/Minecraft.Client/SnowManRenderer.cpp
diff options
context:
space:
mode:
authorvoid_17 <heroerror3@gmail.com>2026-03-02 15:58:20 +0700
committervoid_17 <heroerror3@gmail.com>2026-03-02 15:58:20 +0700
commit7074f35e4ba831e358117842b99ee35b87f85ae5 (patch)
tree7d440d23473196af3056bf2ff4c59d9e740a06f5 /Minecraft.Client/SnowManRenderer.cpp
parentd63f79325f85e014361eb8cf1e41eaebedb1ae71 (diff)
shared_ptr -> std::shared_ptr
This is one of the first commits in a plan to remove all `using namespace std;` lines in the entire codebase as it is considered anti-pattern today.
Diffstat (limited to 'Minecraft.Client/SnowManRenderer.cpp')
-rw-r--r--Minecraft.Client/SnowManRenderer.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/Minecraft.Client/SnowManRenderer.cpp b/Minecraft.Client/SnowManRenderer.cpp
index 83edb3f5..cd08e5ce 100644
--- a/Minecraft.Client/SnowManRenderer.cpp
+++ b/Minecraft.Client/SnowManRenderer.cpp
@@ -13,14 +13,14 @@ SnowManRenderer::SnowManRenderer() : MobRenderer(new SnowManModel(), 0.5f)
this->setArmor(model);
}
-void SnowManRenderer::additionalRendering(shared_ptr<Mob> _mob, float a)
+void SnowManRenderer::additionalRendering(std::shared_ptr<Mob> _mob, float a)
{
// 4J - original version used generics and thus had an input parameter of type SnowMan rather than shared_ptr<Mob> we have here -
// do some casting around instead
- shared_ptr<SnowMan> mob = dynamic_pointer_cast<SnowMan>(_mob);
+ std::shared_ptr<SnowMan> mob = dynamic_pointer_cast<SnowMan>(_mob);
MobRenderer::additionalRendering(mob, a);
- shared_ptr<ItemInstance> headGear = shared_ptr<ItemInstance>( new ItemInstance(Tile::pumpkin, 1) );
+ std::shared_ptr<ItemInstance> headGear = std::shared_ptr<ItemInstance>( new ItemInstance(Tile::pumpkin, 1) );
if (headGear != NULL && headGear->getItem()->id < 256)
{
glPushMatrix();
@@ -13,14 +13,14 @@ SnowManRenderer::SnowManRenderer() : MobRenderer(new SnowManModel(), 0.5f)
{
- // 4J - original version used generics and thus had an input parameter of type SnowMan rather than shared_ptr<Mob> we have here -
+ // 4J - original version used generics and thus had an input parameter of type SnowMan rather than std::shared_ptr<Mob> we have here -
// do some casting around instead